package com.ruoyi.interfaces.service.impl;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.uuid.IdUtils;
import com.ruoyi.interfaces.domain.MdModelFile;
import com.ruoyi.interfaces.domain.MdModelInfo;
import com.ruoyi.interfaces.mapper.MdModelInfoMapper;
import com.ruoyi.interfaces.service.IMdModelFileService;
import com.ruoyi.interfaces.service.IMdModelInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

/**
 * 模型信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-07-15
 */
@Service
public class MdModelInfoServiceImpl implements IMdModelInfoService
{
    @Autowired
    private MdModelInfoMapper mdModelInfoMapper;

    @Autowired
    private IMdModelFileService mdModelFileService;


    /**
     * 查询模型信息
     * 
     * @param mdid 模型信息主键
     * @return 模型信息
     */
    @Override
    public MdModelInfo selectMdModelInfoByMdid(String mdid)
    {
        return mdModelInfoMapper.selectMdModelInfoByMdid(mdid);
    }

    /**
     * 查询模型信息列表
     * 
     * @param mdModelInfo 模型信息
     * @return 模型信息
     */
    @Override
    public List<MdModelInfo> selectMdModelInfoList(MdModelInfo mdModelInfo)
    {
        return mdModelInfoMapper.selectMdModelInfoList(mdModelInfo);
    }

    /**
     * 新增模型信息
     * 
     * @param mdModelInfo 模型信息
     * @return 结果
     */
    @Override
    public String insertMdModelInfo(MdModelInfo mdModelInfo)
    {
        mdModelInfo.setMdid(IdUtils.fastUUID());
        mdModelInfo.setCreateby(DateUtils.getNowDate());
        mdModelInfoMapper.insertMdModelInfo(mdModelInfo);
        return mdModelInfo.getMdid();
    }

    /**
     * 修改模型信息
     * 
     * @param mdModelInfo 模型信息
     * @return 结果
     */
    @Override
    public int updateMdModelInfo(MdModelInfo mdModelInfo)
    {
        mdModelInfo.setModifyby(DateUtils.getNowDate());
        return mdModelInfoMapper.updateMdModelInfo(mdModelInfo);
    }

    /**
     * 批量删除模型信息
     * 
     * @param mdids 需要删除的模型信息主键
     * @return 结果
     */
    @Override
    public int deleteMdModelInfoByMdids(String[] mdids)
    {
        return mdModelInfoMapper.deleteMdModelInfoByMdids(mdids);
    }

    /**
     * 删除模型信息信息
     * 
     * @param mdid 模型信息主键
     * @return 结果
     */
    @Override
    public int deleteMdModelInfoByMdid(String mdid)
    {
        return mdModelInfoMapper.deleteMdModelInfoByMdid(mdid);
    }

    @Override
    public int audit(String[] mdids, String audit) {

        return mdModelInfoMapper.updateMdModelInfoAudit(mdids,audit);
    }
}
